# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/beo/whitepaper/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Beo\\Whitepaper\\": "packages/beo/whitepaper/src",
            "Beo\\Whitepaper\\Seeders\\": "packages/beo/whitepaper/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Beo\Whitepaper\Providers\WhitepaperServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Whitepaper'  => Beo\Whitepaper\Facades\Whitepaper::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Beo\\Whitepaper\\Seeders\\WhitepaperTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Beo\Whitepaper\Providers\WhitepaperServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Beo\Whitepaper\Providers\WhitepaperServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Beo\Whitepaper\Providers\WhitepaperServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/whitepaper/{modulename}

**User**

    http://path-to-route-folder/user/whitepaper/{modulename}

**Public**

    http://path-to-route-folder/whitepapers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/whitepaper/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/whitepaper/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/whitepaper/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/whitepaper/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/whitepaper/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/whitepaper/{modulename}/{slug}
    METHOD: GET