<?php

namespace Beo\Whitepaper\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Beo\Whitepaper\Http\Resources\WhitepaperResource;
use Beo\Whitepaper\Http\Resources\WhitepapersCollection;
use Beo\Whitepaper\Scopes\CategoryPublicScope;
use Beo\Whitepaper\Models\Category;

class CategoryPublicController extends BaseController
{

    /**
     * Show category's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Category::pushScope(new RequestScope())
            ->pushScope(new CategoryPublicScope())
            ->select('categories.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new CategoriesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('whitepaper::category.names'))
            ->view('whitepaper::public.category.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show category.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Category::findBySlug($slug);
        $data = new CategoryResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('whitepaper::category.name'))
            ->view('whitepaper::public.category.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
