<?php

namespace Beo\Whitepaper\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Beo\Whitepaper\Models\Whitepaper;

class WhitepaperPolicy
{

    /**
     * Determine if the given user can view the whitepaper.
     *
     * @param UserPolicyInterface $authUser
     * @param Whitepaper $whitepaper
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Whitepaper $whitepaper)
    {
        if ($authUser->canDo('whitepaper.whitepaper.view') && $authUser->isAdmin()) {
            return true;
        }

        return $whitepaper->user_id == user_id() && $whitepaper->user_type == user_type();
    }

    /**
     * Determine if the given user can create a whitepaper.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('whitepaper.whitepaper.create');
    }

    /**
     * Determine if the given user can update the given whitepaper.
     *
     * @param UserPolicyInterface $authUser
     * @param Whitepaper $whitepaper
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Whitepaper $whitepaper)
    {
        if ($authUser->canDo('whitepaper.whitepaper.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $whitepaper->user_id == user_id() && $whitepaper->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given whitepaper.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Whitepaper $whitepaper)
    {
        return $whitepaper->user_id == user_id() && $whitepaper->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given whitepaper.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Whitepaper $whitepaper)
    {
        if ($authUser->canDo('whitepaper.whitepaper.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given whitepaper.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Whitepaper $whitepaper)
    {
        if ($authUser->canDo('whitepaper.whitepaper.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
