<?php

namespace Beo\Whitepaper\Providers;

use Illuminate\Support\ServiceProvider;
use Beo\Whitepaper\Whitepapers;

class WhitepaperServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'whitepaper');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'whitepaper');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        // $this->registerCommands();

        $this->app->register(\Beo\Whitepaper\Providers\AuthServiceProvider::class);
        $this->app->register(\Beo\Whitepaper\Providers\RouteServiceProvider::class);
        // $this->app->register(\Beo\Whitepaper\Providers\EventServiceProvider::class);
        // $this->app->register(\Beo\Whitepaper\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('beo.whitepaper', function($app)
        {
            return $this->app->make(Whitepapers::class);
        });
    }



    /**
     * Merges user's and whitepaper's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'beo.whitepaper'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/whitepaper.php', 'beo.whitepaper.whitepaper'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/category.php', 'beo.whitepaper.category'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Beo\Whitepaper\Commands\Whitepaper::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['beo.whitepaper'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('beo/whitepaper')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/whitepaper')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/whitepaper')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
